@@ -1,10 +1,9 @@
 #!/usr/bin/env python3
+__version__ = '2.0.4'
 ##########################################################################
 # MFA for AWS CLI using SafeNet Trusted Access (STA)
 ##########################################################################
-# version: 2.0
-# last updated on: 2022-08-26
-#
+# Last updated on: 2022-08-27
 #
 # NOTE: This script was adapted from a script written by Quint Van Deman
 # published on the AWS Security Blog (https://amzn.to/2gT8IAZ). Notable
@@ -26,7 +25,7 @@
 # DISCLAIMER: This script is provided "as-is" without any warranty of
 # any kind, either expressed or implied.
 # ************************************************************************
-# !/usr/bin/python3
+
 import sys
 import boto3
 import requests
@@ -88,6 +87,12 @@ parser = argparse.ArgumentParser(
             epilog="For more info, visit: https://github.com/thalesdemo/sta-awscli"
 )
 
+parser.add_argument(
+        '-v', '--version',
+        action='version',
+        version="%(prog)s v" + __version__
+)
+
 parser.add_argument(
         '-c', '--config',
         required=False,
@@ -279,7 +284,7 @@ def main():
         with open(cli_config_file_path, 'w') as filename:
             config.write(filename)
 
-        print(f"{BColors.OKGREEN}Config file created in: {BColors.ENDC}" + cli_config_file_path)
+        print(f"{BColors.OKGREEN}Config file created in: {BColors.ENDC}" + os.path.abspath(cli_config_file_path))
 
 
     # region: The default AWS region that this script will connect
